@@ -1,7 +1,7 @@
 """
 Type annotations for elb service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/literals/)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/literals.html)
 
 Usage::
 
@@ -25,12 +25,9 @@ __all__ = (
     "DescribeLoadBalancersPaginatorName",
     "InstanceDeregisteredWaiterName",
     "InstanceInServiceWaiterName",
-    "ElasticLoadBalancingServiceName",
     "ServiceName",
-    "ResourceServiceName",
     "PaginatorName",
     "WaiterName",
-    "RegionName",
 )
 
 
@@ -39,7 +36,6 @@ DescribeAccountLimitsPaginatorName = Literal["describe_account_limits"]
 DescribeLoadBalancersPaginatorName = Literal["describe_load_balancers"]
 InstanceDeregisteredWaiterName = Literal["instance_deregistered"]
 InstanceInServiceWaiterName = Literal["instance_in_service"]
-ElasticLoadBalancingServiceName = Literal["elb"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -49,10 +45,12 @@ ServiceName = Literal[
     "amp",
     "amplify",
     "amplifybackend",
+    "amplifyuibuilder",
     "apigateway",
     "apigatewaymanagementapi",
     "apigatewayv2",
     "appconfig",
+    "appconfigdata",
     "appflow",
     "appintegrations",
     "application-autoscaling",
@@ -67,6 +65,7 @@ ServiceName = Literal[
     "autoscaling",
     "autoscaling-plans",
     "backup",
+    "backup-gateway",
     "batch",
     "braket",
     "budgets",
@@ -121,6 +120,7 @@ ServiceName = Literal[
     "dlm",
     "dms",
     "docdb",
+    "drs",
     "ds",
     "dynamodb",
     "dynamodbstreams",
@@ -142,6 +142,7 @@ ServiceName = Literal[
     "emr-containers",
     "es",
     "events",
+    "evidently",
     "finspace",
     "finspace-data",
     "firehose",
@@ -168,6 +169,7 @@ ServiceName = Literal[
     "imagebuilder",
     "importexport",
     "inspector",
+    "inspector2",
     "iot",
     "iot-data",
     "iot-jobs-data",
@@ -181,6 +183,7 @@ ServiceName = Literal[
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
+    "iottwinmaker",
     "iotwireless",
     "ivs",
     "kafka",
@@ -226,7 +229,9 @@ ServiceName = Literal[
     "meteringmarketplace",
     "mgh",
     "mgn",
+    "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhubstrategy",
     "mobile",
     "mq",
     "mturk",
@@ -255,11 +260,13 @@ ServiceName = Literal[
     "qldb-session",
     "quicksight",
     "ram",
+    "rbin",
     "rds",
     "rds-data",
     "redshift",
     "redshift-data",
     "rekognition",
+    "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -269,6 +276,7 @@ ServiceName = Literal[
     "route53-recovery-readiness",
     "route53domains",
     "route53resolver",
+    "rum",
     "s3",
     "s3control",
     "s3outposts",
@@ -326,42 +334,8 @@ ServiceName = Literal[
     "workmail",
     "workmailmessageflow",
     "workspaces",
+    "workspaces-web",
     "xray",
 ]
-ResourceServiceName = Literal[
-    "cloudformation",
-    "cloudwatch",
-    "dynamodb",
-    "ec2",
-    "glacier",
-    "iam",
-    "opsworks",
-    "s3",
-    "sns",
-    "sqs",
-]
 PaginatorName = Literal["describe_account_limits", "describe_load_balancers"]
 WaiterName = Literal["any_instance_in_service", "instance_deregistered", "instance_in_service"]
-RegionName = Literal[
-    "af-south-1",
-    "ap-east-1",
-    "ap-northeast-1",
-    "ap-northeast-2",
-    "ap-northeast-3",
-    "ap-south-1",
-    "ap-southeast-1",
-    "ap-southeast-2",
-    "ca-central-1",
-    "eu-central-1",
-    "eu-north-1",
-    "eu-south-1",
-    "eu-west-1",
-    "eu-west-2",
-    "eu-west-3",
-    "me-south-1",
-    "sa-east-1",
-    "us-east-1",
-    "us-east-2",
-    "us-west-1",
-    "us-west-2",
-]
